// src/compiler/template.ts
import path from "path";
import MagicString from "magic-string";
import { parse, transform } from "@vue/compiler-dom";
var EXCLUDE_TAG = ["template", "script", "style"];
async function compileSFCTemplate({ code, id, type }) {
  const s = new MagicString(code);
  const ast = parse(code, { comments: true });
  const result = await new Promise((resolve) => {
    transform(ast, {
      nodeTransforms: [
        (node) => {
          if (node.type === 1) {
            if (node.tagType === 0 && !EXCLUDE_TAG.includes(node.tag)) {
              const { base } = path.parse(id);
              if (node.loc.source.includes("data-v-inspector-file"))
                return;
              const insertPosition = node.loc.start.offset + node.tag.length + 1;
              const { line, column } = node.loc.start;
              const content = {
                template: ` data-v-inspector-file="${id}" data-v-inspector-line=${line} data-v-inspector-column=${column} data-v-inspector-title="${base}"`,
                jsx: ` data-v-inspector-file="${id}" data-v-inspector-line={${line}} data-v-inspector-column={${column}} data-v-inspector-title="${base}"`
              }[type];
              s.prependLeft(insertPosition, content);
            }
          }
        }
      ]
    });
    resolve(s.toString());
  });
  return result;
}

// src/utils/index.ts
import MagicString2 from "magic-string";
function parseVueRequest(id) {
  const [filename] = id.split("?", 2);
  const url = new URL(id, "http://domain.inspector");
  const query = Object.fromEntries(url.searchParams.entries());
  if (query.vue != null)
    query.vue = true;
  if (query.src != null)
    query.src = true;
  if (query.index != null)
    query.index = Number(query.index);
  if (query.raw != null)
    query.raw = true;
  if (query.hasOwnProperty("lang.tsx") || query.hasOwnProperty("lang.jsx"))
    query.isJsx = true;
  return {
    filename,
    query
  };
}
function normalizeOverlayScripts({ hash, scripts }) {
  const s = new MagicString2(scripts);
  s.replace(/browserHash/g, hash);
  return s.toString();
}

// src/overlay/index.json
var v2 = {
  scripts: `import Vue from "/node_modules/.vite/deps/vue.js?v=browserHash"
var render = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('div',{staticClass:"vue-inspector-control",class:{disabled: _vm.disabled},style:(_vm.controlStyle),on:{"click":function($event){$event.stopPropagation();return _vm.toggleControl.apply(null, arguments)}}},[_c('img',{ref:"target",attrs:{"id":"vueInspectorControl","src":"https://github.com/webfansplz/vite-plugin-vue-inspector/blob/main/docs/images/logo.png?raw=true","alt":"logo","draggable":"false"}})]),_vm._v(" "),(_vm.overlayVisible)?_c('ul',{ref:"overlayTarget",staticClass:"vue-inspector-overlay",style:(_vm.overlayStyle)},[_c('li',[_vm._v("\\n        file: "),_c('em',[_vm._v(_vm._s(("<" + (_vm.navigationParams.title) + ">")))])]),_vm._v(" "),_c('li',[_vm._v("\\n        line: "),_c('em',[_vm._v(_vm._s(_vm.navigationParams.line))])]),_vm._v(" "),_c('li',[_vm._v("\\n        column: "),_c('em',[_vm._v(_vm._s(_vm.navigationParams.column))])])]):_vm._e()])}


const App =  {
  data() {
    return {
      target: null,
      overlayTarget: null,
      disabled: !window.__VUE_INSPECTOR_INITIAL_ENABLED__,
      overlayVisible: false,

      navigationParams: {
        file: "",
        line: 0,
        column: 0,
      },
      position: {
        x: 0,
        y: 0,
      },

      // drag control
      controlPosition: {
        x: 0,
        y: 0,
      },
      pressedDelta: undefined,
    }
  },
  computed: {
    controlStyle() {
      const left = this.controlPosition.x || window.clientWidth
      const top = this.controlPosition.y || 20
      return \`left:\${left}px;top:\${top}px;\`
    },
    overlayStyle() {
      return {
        left: \`\${
          this.position.x - this.$refs.overlayTarget?.clientWidth / 2 || 0
        }px\`,
        top: \`\${this.position.y + 20}px\`,
      }
    },
  },
  mounted() {
    this.$refs.target?.addEventListener("pointerdown", this.dragStart, true)
    window.addEventListener("pointermove", this.dragMove, true)
    window.addEventListener("pointerup", this.dragEnd, true)

    window.addEventListener("click", this.onFetch)
    window.addEventListener("mousemove", this.onMouseMove)
  },
  methods: {
    dragStart(e) {
      e.stopPropagation()
      if (e.target !== this.$refs.target) return
      const rect = this.$refs.target?.getBoundingClientRect()
      const pos = {
        x: e.pageX - rect.left,
        y: e.pageY - rect.top,
      }
      this.pressedDelta = pos
    },
    dragMove(e) {
      if (!this.pressedDelta) return
      this.controlPosition = {
        x: e.pageX - this.pressedDelta.x,
        y: e.pageY - this.pressedDelta.y,
      }
    },
    dragEnd() {
      if (!this.pressedDelta) return
      this.pressedDelta = undefined
    },

    toggleControl() {
      this.disabled = !this.disabled
    },
    getTargetNode(e) {
      const path = e.path ?? e.composedPath()
      const targetNode = path?.find(node => node?.hasAttribute?.("data-v-inspector-file"))
      if (targetNode?.id === "vueInspectorControl") {
        return {
          targetNode: null,
          params: null,
        }
      }
      return {
        targetNode,
        params: targetNode
          ? {
            file: targetNode?.getAttribute?.("data-v-inspector-file"),
            line: targetNode?.getAttribute?.("data-v-inspector-line"),
            column: targetNode?.getAttribute?.("data-v-inspector-column"),
            title: targetNode?.getAttribute?.("data-v-inspector-title"),
          }
          : null,
      }
    },
    onFetch(e) {
      if (this.disabled) return
      e.preventDefault()
      const { targetNode, params } = this.getTargetNode(e)
      if (!targetNode) return
      const { file, line, column } = params
      fetch(
        \`/__open-stack-frame-in-editor?file=\${file}&line=\${line}&column=\${column}\`,
      )
      this.overlayVisible = false
    },
    onMouseMove(e) {
      if (this.disabled) return
      const { targetNode, params } = this.getTargetNode(e)
      if (targetNode) {
        this.position.x = e.pageX
        this.position.y = e.pageY
        this.overlayVisible = true
        this.navigationParams = params
      }
      else {
        this.overlayVisible = false
        this.navigationParams = {
          file: "",
          line: 0,
          column: 0,
        }
      }
    },
  },
}
App.render = render
    new Vue({
    render: h => h(App),
  }).$mount("#vite_vue_inspector_overlay_container")
  `,
  overlayContainerScript: "\n    const container = document.createElement('div')\n    container.style.position = 'fixed'\n    container.id = 'vite_vue_inspector_overlay_container'\n    document.body.appendChild(container)\n  ",
  styles: "\n.vue-inspector-control {\n  cursor: pointer;\n  position: fixed;\n  text-align: center;\n  right: 20px;\n  top: 20px;\n  z-index: 100000;\n  width: 90px;\n  height: 90px;\n  background-color: #fff;\n  border: 2px solid #29a8f2;\n  border-radius: 50%;\n}\n.vue-inspector-control img {\n  width: 80px;\n}\n.vue-inspector-control:hover {\n  background-color: #29a8f2;\n}\n.vue-inspector-control.disabled {\n  border: 2px dashed #ccc;\n}\n.vue-inspector-control.disabled:hover {\n  background-color: #ccc;\n}\n.vue-inspector-control.disabled img {\n  opacity: 0.5;\n}\n.vue-inspector-overlay {\n  position: fixed;\n  border: 2px dashed #666;\n  background-color: rgba(0,0,0,0.8);\n  color: #fff;\n  padding: 10px;\n  border-radius: 5px;\n  text-align: left;\n}\n.vue-inspector-overlay em {\n  font-style: normal;\n  font-weight: 500;\n}\n"
};
var v3 = {
  scripts: 'import { createCommentVNode as _createCommentVNode, createElementVNode as _createElementVNode, withModifiers as _withModifiers, normalizeClass as _normalizeClass, normalizeStyle as _normalizeStyle, toDisplayString as _toDisplayString, createTextVNode as _createTextVNode, openBlock as _openBlock, createElementBlock as _createElementBlock } from "/node_modules/.vite/deps/vue.js?v=browserHash"\n\nconst _hoisted_1 = {\n  id: "vueInspectorControl",\n  ref: "target",\n  src: "https://github.com/webfansplz/vite-plugin-vue-inspector/blob/main/docs/images/logo.png?raw=true",\n  alt: "logo",\n  draggable: "false"\n}\nconst _hoisted_2 = /*#__PURE__*/_createTextVNode(" file: ")\nconst _hoisted_3 = /*#__PURE__*/_createTextVNode(" line: ")\nconst _hoisted_4 = /*#__PURE__*/_createTextVNode(" column: ")\n\nexport function render(_ctx, _cache) {\n  return (_openBlock(), _createElementBlock("div", null, [\n    _createCommentVNode(" switch control "),\n    _createElementVNode("div", {\n      class: _normalizeClass(["vue-inspector-control", {disabled: _ctx.disabled}]),\n      style: _normalizeStyle(_ctx.controlStyle),\n      onClick: _cache[0] || (_cache[0] = _withModifiers((...args) => (_ctx.toggleControl && _ctx.toggleControl(...args)), ["stop"]))\n    }, [\n      _createElementVNode("img", _hoisted_1, null, 512 /* NEED_PATCH */)\n    ], 6 /* CLASS, STYLE */),\n    _createCommentVNode(" overlay "),\n    (_ctx.overlayVisible)\n      ? (_openBlock(), _createElementBlock("ul", {\n          key: 0,\n          ref: "overlayTarget",\n          class: "vue-inspector-overlay",\n          style: _normalizeStyle(_ctx.overlayStyle)\n        }, [\n          _createElementVNode("li", null, [\n            _hoisted_2,\n            _createElementVNode("em", null, _toDisplayString(`<${_ctx.navigationParams.title}>`), 1 /* TEXT */)\n          ]),\n          _createElementVNode("li", null, [\n            _hoisted_3,\n            _createElementVNode("em", null, _toDisplayString(_ctx.navigationParams.line), 1 /* TEXT */)\n          ]),\n          _createElementVNode("li", null, [\n            _hoisted_4,\n            _createElementVNode("em", null, _toDisplayString(_ctx.navigationParams.column), 1 /* TEXT */)\n          ])\n        ], 4 /* STYLE */))\n      : _createCommentVNode("v-if", true)\n  ]))\n}\nconst App =  {\n  data() {\n    return {\n      target: null,\n      overlayTarget: null,\n      disabled: !window.__VUE_INSPECTOR_INITIAL_ENABLED__,\n      overlayVisible: false,\n\n      navigationParams: {\n        file: "",\n        line: 0,\n        column: 0,\n      },\n      position: {\n        x: 0,\n        y: 0,\n      },\n\n      // drag control\n      controlPosition: {\n        x: 0,\n        y: 0,\n      },\n      pressedDelta: undefined,\n    }\n  },\n  computed: {\n    controlStyle() {\n      const left = this.controlPosition.x || window.clientWidth\n      const top = this.controlPosition.y || 20\n      return `left:${left}px;top:${top}px;`\n    },\n    overlayStyle() {\n      return {\n        left: `${\n          this.position.x - this.$refs.overlayTarget?.clientWidth / 2 || 0\n        }px`,\n        top: `${this.position.y + 20}px`,\n      }\n    },\n  },\n  mounted() {\n    this.$refs.target?.addEventListener("pointerdown", this.dragStart, true)\n    window.addEventListener("pointermove", this.dragMove, true)\n    window.addEventListener("pointerup", this.dragEnd, true)\n\n    window.addEventListener("click", this.onFetch)\n    window.addEventListener("mousemove", this.onMouseMove)\n  },\n  methods: {\n    dragStart(e) {\n      e.stopPropagation()\n      if (e.target !== this.$refs.target) return\n      const rect = this.$refs.target?.getBoundingClientRect()\n      const pos = {\n        x: e.pageX - rect.left,\n        y: e.pageY - rect.top,\n      }\n      this.pressedDelta = pos\n    },\n    dragMove(e) {\n      if (!this.pressedDelta) return\n      this.controlPosition = {\n        x: e.pageX - this.pressedDelta.x,\n        y: e.pageY - this.pressedDelta.y,\n      }\n    },\n    dragEnd() {\n      if (!this.pressedDelta) return\n      this.pressedDelta = undefined\n    },\n\n    toggleControl() {\n      this.disabled = !this.disabled\n    },\n    getTargetNode(e) {\n      const path = e.path ?? e.composedPath()\n      const targetNode = path?.find(node => node?.hasAttribute?.("data-v-inspector-file"))\n      if (targetNode?.id === "vueInspectorControl") {\n        return {\n          targetNode: null,\n          params: null,\n        }\n      }\n      return {\n        targetNode,\n        params: targetNode\n          ? {\n            file: targetNode?.getAttribute?.("data-v-inspector-file"),\n            line: targetNode?.getAttribute?.("data-v-inspector-line"),\n            column: targetNode?.getAttribute?.("data-v-inspector-column"),\n            title: targetNode?.getAttribute?.("data-v-inspector-title"),\n          }\n          : null,\n      }\n    },\n    onFetch(e) {\n      if (this.disabled) return\n      e.preventDefault()\n      const { targetNode, params } = this.getTargetNode(e)\n      if (!targetNode) return\n      const { file, line, column } = params\n      fetch(\n        `/__open-stack-frame-in-editor?file=${file}&line=${line}&column=${column}`,\n      )\n      this.overlayVisible = false\n    },\n    onMouseMove(e) {\n      if (this.disabled) return\n      const { targetNode, params } = this.getTargetNode(e)\n      if (targetNode) {\n        this.position.x = e.pageX\n        this.position.y = e.pageY\n        this.overlayVisible = true\n        this.navigationParams = params\n      }\n      else {\n        this.overlayVisible = false\n        this.navigationParams = {\n          file: "",\n          line: 0,\n          column: 0,\n        }\n      }\n    },\n  },\n}\nApp.render = render\n    import { createApp } from "/node_modules/.vite/deps/vue.js?v=browserHash"\n    createApp(App).mount(\'#vite_vue_inspector_overlay_container\')\n  ',
  overlayContainerScript: "\n    const container = document.createElement('div')\n    container.style.position = 'fixed'\n    container.id = 'vite_vue_inspector_overlay_container'\n    document.body.appendChild(container)\n  ",
  styles: "\n.vue-inspector-control {\n  cursor: pointer;\n  position: fixed;\n  text-align: center;\n  right: 20px;\n  top: 20px;\n  z-index: 100000;\n  width: 90px;\n  height: 90px;\n  background-color: #fff;\n  border: 2px solid #29a8f2;\n  border-radius: 50%;\n}\n.vue-inspector-control img {\n  width: 80px;\n}\n.vue-inspector-control:hover {\n  background-color: #29a8f2;\n}\n.vue-inspector-control.disabled {\n  border: 2px dashed #ccc;\n}\n.vue-inspector-control.disabled:hover {\n  background-color: #ccc;\n}\n.vue-inspector-control.disabled img {\n  opacity: 0.5;\n}\n.vue-inspector-overlay {\n  position: fixed;\n  border: 2px dashed #666;\n  background-color: rgba(0,0,0,0.8);\n  color: #fff;\n  padding: 10px;\n  border-radius: 5px;\n  text-align: left;\n}\n.vue-inspector-overlay em {\n  font-style: normal;\n  font-weight: 500;\n}\n"
};

// src/launch-editor.ts
import fs from "fs";
import path2 from "path";
import child_process from "child_process";
import os from "os";
import chalk from "chalk";
import shellQuote from "shell-quote";
function isTerminalEditor(editor) {
  switch (editor) {
    case "vim":
    case "emacs":
    case "nano":
      return true;
  }
  return false;
}
var COMMON_EDITORS_OSX = {
  "/Applications/Atom.app/Contents/MacOS/Atom": "atom",
  "/Applications/Atom Beta.app/Contents/MacOS/Atom Beta": "/Applications/Atom Beta.app/Contents/MacOS/Atom Beta",
  "/Applications/Brackets.app/Contents/MacOS/Brackets": "brackets",
  "/Applications/Sublime Text.app/Contents/MacOS/Sublime Text": "/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl",
  "/Applications/Sublime Text Dev.app/Contents/MacOS/Sublime Text": "/Applications/Sublime Text Dev.app/Contents/SharedSupport/bin/subl",
  "/Applications/Sublime Text 2.app/Contents/MacOS/Sublime Text 2": "/Applications/Sublime Text 2.app/Contents/SharedSupport/bin/subl",
  "/Applications/Visual Studio Code.app/Contents/MacOS/Electron": "code",
  "/Applications/Visual Studio Code - Insiders.app/Contents/MacOS/Electron": "code-insiders",
  "/Applications/VSCodium.app/Contents/MacOS/Electron": "vscodium",
  "/Applications/AppCode.app/Contents/MacOS/appcode": "/Applications/AppCode.app/Contents/MacOS/appcode",
  "/Applications/CLion.app/Contents/MacOS/clion": "/Applications/CLion.app/Contents/MacOS/clion",
  "/Applications/IntelliJ IDEA.app/Contents/MacOS/idea": "/Applications/IntelliJ IDEA.app/Contents/MacOS/idea",
  "/Applications/PhpStorm.app/Contents/MacOS/phpstorm": "/Applications/PhpStorm.app/Contents/MacOS/phpstorm",
  "/Applications/PyCharm.app/Contents/MacOS/pycharm": "/Applications/PyCharm.app/Contents/MacOS/pycharm",
  "/Applications/PyCharm CE.app/Contents/MacOS/pycharm": "/Applications/PyCharm CE.app/Contents/MacOS/pycharm",
  "/Applications/RubyMine.app/Contents/MacOS/rubymine": "/Applications/RubyMine.app/Contents/MacOS/rubymine",
  "/Applications/WebStorm.app/Contents/MacOS/webstorm": "/Applications/WebStorm.app/Contents/MacOS/webstorm",
  "/Applications/MacVim.app/Contents/MacOS/MacVim": "mvim",
  "/Applications/GoLand.app/Contents/MacOS/goland": "/Applications/GoLand.app/Contents/MacOS/goland",
  "/Applications/Rider.app/Contents/MacOS/rider": "/Applications/Rider.app/Contents/MacOS/rider"
};
var COMMON_EDITORS_LINUX = {
  "atom": "atom",
  "Brackets": "brackets",
  "code": "code",
  "code-insiders": "code-insiders",
  "vscodium": "vscodium",
  "emacs": "emacs",
  "gvim": "gvim",
  "idea.sh": "idea",
  "phpstorm.sh": "phpstorm",
  "pycharm.sh": "pycharm",
  "rubymine.sh": "rubymine",
  "sublime_text": "sublime_text",
  "vim": "vim",
  "webstorm.sh": "webstorm",
  "goland.sh": "goland",
  "rider.sh": "rider"
};
var COMMON_EDITORS_WIN = [
  "Brackets.exe",
  "Code.exe",
  "Code - Insiders.exe",
  "VSCodium.exe",
  "atom.exe",
  "sublime_text.exe",
  "notepad++.exe",
  "clion.exe",
  "clion64.exe",
  "idea.exe",
  "idea64.exe",
  "phpstorm.exe",
  "phpstorm64.exe",
  "pycharm.exe",
  "pycharm64.exe",
  "rubymine.exe",
  "rubymine64.exe",
  "webstorm.exe",
  "webstorm64.exe",
  "goland.exe",
  "goland64.exe",
  "rider.exe",
  "rider64.exe"
];
var WINDOWS_FILE_NAME_WHITELIST = /^([A-Za-z]:[/\\])?(?:[\x2D-9A-Z\\_a-z\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0560-\u0588\u05D0-\u05EA\u05EF-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u0860-\u086A\u08A0-\u08B4\u08B6-\u08BD\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u09FC\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0AF9\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58-\u0C5A\u0C60\u0C61\u0C80\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D54-\u0D56\u0D5F-\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F5\u13F8-\u13FD\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16F1-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1878\u1880-\u1884\u1887-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1C80-\u1C88\u1C90-\u1CBA\u1CBD-\u1CBF\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312F\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FEF\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA7B9\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA8FD\uA8FE\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB65\uAB70-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF2D-\uDF40\uDF42-\uDF49\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF]|\uD801[\uDC00-\uDC9D\uDCB0-\uDCD3\uDCD8-\uDCFB\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDCE0-\uDCF2\uDCF4\uDCF5\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE35\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48\uDC80-\uDCB2\uDCC0-\uDCF2\uDD00-\uDD23\uDF00-\uDF1C\uDF27\uDF30-\uDF45]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD44\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDDDC\uDE00-\uDE11\uDE13-\uDE2B\uDE80-\uDE86\uDE88\uDE8A-\uDE8D\uDE8F-\uDE9D\uDE9F-\uDEA8\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF50\uDF5D-\uDF61]|\uD805[\uDC00-\uDC34\uDC47-\uDC4A\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDDD8-\uDDDB\uDE00-\uDE2F\uDE44\uDE80-\uDEAA\uDF00-\uDF1A]|\uD806[\uDC00-\uDC2B\uDCA0-\uDCDF\uDCFF\uDE00\uDE0B-\uDE32\uDE3A\uDE50\uDE5C-\uDE83\uDE86-\uDE89\uDE9D\uDEC0-\uDEF8]|\uD807[\uDC00-\uDC08\uDC0A-\uDC2E\uDC40\uDC72-\uDC8F\uDD00-\uDD06\uDD08\uDD09\uDD0B-\uDD30\uDD46\uDD60-\uDD65\uDD67\uDD68\uDD6A-\uDD89\uDD98\uDEE0-\uDEF2]|\uD808[\uDC00-\uDF99]|\uD809[\uDC80-\uDD43]|[\uD80C\uD81C-\uD820\uD840-\uD868\uD86A-\uD86C\uD86F-\uD872\uD874-\uD879][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD811[\uDC00-\uDE46]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDE40-\uDE7F\uDF00-\uDF44\uDF50\uDF93-\uDF9F\uDFE0\uDFE1]|\uD821[\uDC00-\uDFF1]|\uD822[\uDC00-\uDEF2]|\uD82C[\uDC00-\uDD1E\uDD70-\uDEFB]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4\uDD00-\uDD43]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D\uDC20-\uDFFF]|\uD873[\uDC00-\uDEA1\uDEB0-\uDFFF]|\uD87A[\uDC00-\uDFE0]|\uD87E[\uDC00-\uDE1D])+$/;
function addWorkspaceToArgumentsIfExists(args, workspace) {
  if (workspace)
    args.unshift(workspace);
  return args;
}
function getArgumentsForLineNumber(editor, fileName, lineNumber, colNumber, workspace) {
  const editorBasename = path2.basename(editor).replace(/\.(exe|cmd|bat)$/i, "");
  switch (editorBasename) {
    case "atom":
    case "Atom":
    case "Atom Beta":
    case "subl":
    case "sublime":
    case "sublime_text":
      return [`${fileName}:${lineNumber}:${colNumber}`];
    case "wstorm":
    case "charm":
      return [`${fileName}:${lineNumber}`];
    case "notepad++":
      return [`-n${lineNumber}`, `-c${colNumber}`, fileName];
    case "vim":
    case "mvim":
    case "joe":
    case "gvim":
      return [`+${lineNumber}`, fileName];
    case "emacs":
    case "emacsclient":
      return [`+${lineNumber}:${colNumber}`, fileName];
    case "rmate":
    case "mate":
    case "mine":
      return ["--line", lineNumber, fileName];
    case "code":
    case "Code":
    case "code-insiders":
    case "Code - Insiders":
    case "vscodium":
    case "VSCodium":
      return addWorkspaceToArgumentsIfExists(["-g", `${fileName}:${lineNumber}:${colNumber}`], workspace);
    case "appcode":
    case "clion":
    case "clion64":
    case "idea":
    case "idea64":
    case "phpstorm":
    case "phpstorm64":
    case "pycharm":
    case "pycharm64":
    case "rubymine":
    case "rubymine64":
    case "webstorm":
    case "webstorm64":
    case "goland":
    case "goland64":
    case "rider":
    case "rider64":
      return addWorkspaceToArgumentsIfExists(["--line", lineNumber, fileName], workspace);
  }
  return [fileName];
}
function guessEditor() {
  if (process.env.VUE_EDITOR)
    return shellQuote.parse(process.env.VUE_EDITOR);
  try {
    if (process.platform === "darwin") {
      const output = child_process.execSync("ps x").toString();
      const processNames = Object.keys(COMMON_EDITORS_OSX);
      for (let i = 0; i < processNames.length; i++) {
        const processName = processNames[i];
        if (output.indexOf(processName) !== -1)
          return [COMMON_EDITORS_OSX[processName]];
      }
    } else if (process.platform === "win32") {
      const output = child_process.execSync('wmic process where "executablepath is not null" get executablepath').toString();
      const runningProcesses = output.split("\r\n");
      for (let i = 0; i < runningProcesses.length; i++) {
        const processPath = runningProcesses[i].trim();
        const processName = path2.basename(processPath);
        if (COMMON_EDITORS_WIN.indexOf(processName) !== -1)
          return [processPath];
      }
    } else if (process.platform === "linux") {
      const output = child_process.execSync("ps x --no-heading -o comm --sort=comm").toString();
      const processNames = Object.keys(COMMON_EDITORS_LINUX);
      for (let i = 0; i < processNames.length; i++) {
        const processName = processNames[i];
        if (output.indexOf(processName) !== -1)
          return [COMMON_EDITORS_LINUX[processName]];
      }
    }
  } catch (error) {
  }
  if (process.env.VISUAL)
    return [process.env.VISUAL];
  else if (process.env.EDITOR)
    return [process.env.EDITOR];
  return [null];
}
function printInstructions(fileName, errorMessage) {
  console.log();
  console.log(chalk.red(`Could not open ${path2.basename(fileName)} in the editor.`));
  if (errorMessage) {
    if (errorMessage[errorMessage.length - 1] !== ".")
      errorMessage += ".";
    console.log(chalk.red(`The editor process exited with an error: ${errorMessage}`));
  }
  console.log();
  console.log(`To set up the editor integration, add something like ${chalk.cyan("VUE_EDITOR=atom")} to the ${chalk.green(".env.local")} file in your project folder and restart the development server. Learn more: ${chalk.green("https://goo.gl/MMTaZt")}`);
  console.log();
}
var _childProcess = null;
function launchEditor(fileName, lineNumber, colNumber) {
  if (!fs.existsSync(fileName))
    return;
  if (!(Number.isInteger(lineNumber) && lineNumber > 0))
    return;
  if (!(Number.isInteger(colNumber) && colNumber > 0))
    colNumber = 1;
  let [editor, ...args] = guessEditor();
  if (!editor) {
    printInstructions(fileName, null);
    return;
  }
  if (editor.toLowerCase() === "none")
    return;
  if (process.platform === "linux" && fileName.startsWith("/mnt/") && /Microsoft/i.test(os.release())) {
    fileName = path2.relative("", fileName);
  }
  if (process.platform === "win32" && !WINDOWS_FILE_NAME_WHITELIST.test(fileName.trim())) {
    console.log();
    console.log(chalk.red(`Could not open ${path2.basename(fileName)} in the editor.`));
    console.log();
    console.log("When running on Windows, file names are checked against a whitelist to protect against remote code execution attacks. File names may consist only of alphanumeric characters (all languages), periods, dashes, slashes, and underscores.");
    console.log();
    return;
  }
  const workspace = null;
  if (lineNumber) {
    args = args.concat(getArgumentsForLineNumber(editor, fileName, lineNumber, colNumber, workspace));
  } else {
    args.push(fileName);
  }
  if (_childProcess && isTerminalEditor(editor)) {
    _childProcess.kill("SIGKILL");
  }
  if (process.platform === "win32") {
    _childProcess = child_process.spawn("cmd.exe", ["/C", editor].concat(args), { stdio: "inherit" });
  } else {
    _childProcess = child_process.spawn(editor, args, { stdio: "inherit" });
  }
  _childProcess.on("exit", (errorCode) => {
    _childProcess = null;
    if (errorCode)
      printInstructions(fileName, `(code ${errorCode})`);
  });
  _childProcess.on("error", (error) => {
    printInstructions(fileName, error.message);
  });
}

// src/middleware.ts
var SERVER_URL = "/__open-stack-frame-in-editor";
var queryParserMiddleware = (req, _, next) => {
  var _a;
  if (!req.query && ((_a = req.url) == null ? void 0 : _a.startsWith(SERVER_URL))) {
    const url = new URL(req.url, "http://domain.inspector");
    req.query = Object.fromEntries(url.searchParams.entries());
  }
  next();
};
var launchEditorMiddleware = (req, res, next) => {
  if (req.url.startsWith(SERVER_URL)) {
    const { file, line, column } = req.query;
    if (!file) {
      res.statusCode = 500;
      res.end('launch-editor-middleware: required query param "file" is missing.');
    }
    const lineNumber = +line || 1;
    const columnNumber = +column || 1;
    launchEditor(file, lineNumber, columnNumber);
    res.end();
  } else {
    next();
  }
};

// src/index.ts
function VitePluginInspector(options = { vue: 3, enabled: true }) {
  const { scripts, styles, overlayContainerScript } = options.vue === 2 ? v2 : v3;
  return {
    name: "vite-plugin-vue-inspector",
    enforce: "pre",
    apply: "serve",
    transform(code, id) {
      const { filename, query } = parseVueRequest(id);
      const isJsx = filename.endsWith(".jsx") || filename.endsWith(".tsx") || filename.endsWith(".vue") && query.isJsx;
      const isTpl = filename.endsWith(".vue") && query.type !== "style";
      if (isJsx || isTpl)
        return compileSFCTemplate({ code, id: filename, type: isJsx ? "jsx" : "template" });
      return code;
    },
    configureServer(server) {
      server.middlewares.use(queryParserMiddleware);
      server.middlewares.use(launchEditorMiddleware);
    },
    transformIndexHtml(html, { server }) {
      var _a, _b, _c, _d, _e, _f;
      const _server = server;
      const browserHash = (_e = (_d = (_b = (_a = _server == null ? void 0 : _server._optimizedDeps) == null ? void 0 : _a.metadata) == null ? void 0 : _b.browserHash) != null ? _d : (_c = _server == null ? void 0 : _server._optimizeDepsMetadata) == null ? void 0 : _c.browserHash) != null ? _e : "";
      return {
        html,
        tags: [{
          tag: "script",
          children: `window.__VUE_INSPECTOR_INITIAL_ENABLED__=${(_f = options.enabled) != null ? _f : true};${overlayContainerScript}`,
          injectTo: "body"
        }, {
          tag: "script",
          attrs: {
            type: "module"
          },
          children: normalizeOverlayScripts({
            hash: browserHash,
            scripts
          }),
          injectTo: "body"
        }, {
          tag: "style",
          children: styles,
          injectTo: "head"
        }]
      };
    }
  };
}
var src_default = VitePluginInspector;
export {
  src_default as default
};
